@@ -7,7 +7,6 @@ old_opts = options(
 # https://github.com/HenrikBengtsson/Wishlist-for-R/issues/88
 old_opts = lapply(old_opts, function(x) if (is.null(x)) FALSE else x)
 
-lg_rush = lgr::get_logger("rush")
-old_threshold_rush = lg_rush$threshold
-lg_rush$set_threshold(0)
-
+lg = lgr::get_logger("mlr3")
+old_threshold = lg$threshold
+lg$set_threshold(0)
